#
# spec file for package python-panel
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

# truncate trailing suffix
%define distversion 1.5
Name:           python-panel%{psuffix}
Version:        1.5.0
Release:        2.1
Summary:        A high level app and dashboarding solution for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/holoviz/panel
Source0:        https://files.pythonhosted.org/packages/source/p/panel/panel-%{version}.tar.gz
# package-lock.json file generated with procedure:
# - delete old package-lock.json in panel subdirectory
# - add '"typescript": "^4.2.0"' to package.json devDependencies
# - npm install --package-lock-only --legacy-peer-deps --ignore-scripts
Source10:       package-lock.json
# node_modules generated using "osc service mr" with https://github.com/openSUSE/obs-service-node_modules
Source11:       node_modules.spec.inc
Source99:       python-panel-rpmlintrc
%include        %{_sourcedir}/node_modules.spec.inc
# PATCH-FEATURE-OPENSUSE exclude-package-lock.patch boo#1231254 gh#openSUSE/obs-service-node_modules#41
Patch0:         exclude-package-lock.patch
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module bleach}
BuildRequires:  %{python_module bokeh >= 3.5.0 with %python-bokeh < 3.6}
BuildRequires:  %{python_module hatch-vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module param >= 2.1.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyviz-comms >= 2.0.0}
BuildRequires:  %{python_module requests}
BuildRequires:  fdupes
BuildRequires:  jupyter-notebook-filesystem
BuildRequires:  local-npm-registry
BuildRequires:  python-rpm-macros
Requires:       python-Markdown
Requires:       python-bleach
Requires:       python-linkify-it-py
Requires:       python-markdown-it-py
Requires:       python-mdit-py-plugins
Requires:       python-packaging
Requires:       python-pandas >= 1.2
Requires:       python-pyviz_comms >= 2.0.0
Requires:       python-requests
Requires:       python-tqdm
Requires:       python-typing_extensions
Requires:       (python-bokeh >= 3.5.0 with python-bokeh < 3.6)
Requires:       (python-param >= 2.1 with python-param < 3)
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     jupyter-panel
Recommends:     python-Pillow
Recommends:     python-holoviews >= 1.16.0
Recommends:     python-jupyterlab
Recommends:     python-matplotlib
Recommends:     python-plotly
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module panel = %{version}}
##
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module altair}
BuildRequires:  %{python_module diskcache}
BuildRequires:  %{python_module holoviews >= 1.16.0}
BuildRequires:  %{python_module jupyterlab}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module plotly}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-rerunfailures}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module streamz}
BuildRequires:  unzip
# Tests segfault
# BuildRequires:  %%{python_module vtk}
%endif
%python_subpackages

%description
Panel is a Python library that lets you create custom interactive web apps and
dashboards by connecting user-defined widgets to plots, images, tables, or
text.

%package     -n jupyter-panel
Summary:        Jupyter notebook and server cofiguration for python-panel
Group:          Development/Languages/Python
# Any flavor is okay, but suggest the primary one for automatic zypper choice -- boo#1214354
Requires:       python3dist(panel) = %{distversion}
Requires:       jupyter-bokeh
Suggests:       python3-panel

%description -n jupyter-panel
Panel is a Python library that lets you create custom interactive web apps and
dashboards by connecting user-defined widgets to plots, images, tables, or
text.

This package contains the notebook and server extension configuration common
to all Python flavors.

%prep
%autosetup -p1 -n panel-%{version}
# no color for pytest
sed -i '/addopts/ s/--color=yes//' pyproject.toml
rm panel/.eslintrc.js
for p in panel/tests/io/reload_module.py
do \
    [ -f $p -a ! -s $p ] || exit 1 && echo "# Empty module" > $p
done
# Resources are already bundled in sdist
sed -i 's|bundle_resources()$|assert os.path.exists("panel/dist/bundled/font-awesome")|' hatch_build.py
# npm registry for Source10 provided in Source11
pushd panel
rm package-lock.json
local-npm-registry %{_sourcedir} install --include=dev --include=peer
popd
sed -i /asyncio_default_fixture_loop_scope/d pyproject.toml

%if ! %{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/panel
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
export PYTEST_DEBUG_TEMPROOT=$(mktemp -d -p ./)
# flaky async test
donttest="test_server_async_callbacks"
# flaky timeout
donttest="$donttest or test_server_thread_pool_change_event or test_server_on_load_after_init"
# upstream skips it for win and osx, we skip it because it (flakily) terminates everything on aarch64
donttest="$donttest or (test_terminal and test_subprocess)"
# file sample.pdf missing
donttest="$donttest or test_pdf_local_file"
# Don't test on 32-bit: asyncio is too flaky
[ $(getconf LONG_BIT) -eq 32 ] && exit 0
# no network connection in obs
deselectmark=(-m "not internet")
# no multiflavor playwright
ignorefiles=(--ignore scripts/panelite/test/test_utils.py --ignore scripts/panelite/test/test_panelite.py)
%pytest -n auto -rsfE -k "not ($donttest)" "${deselectmark[@]}" "${ignorefiles[@]}"
%endif

%post
%python_install_alternative panel

%postun
%python_uninstall_alternative panel

%if ! %{with test}
%files %{python_files}
%license LICENSE.txt
%doc README.md
%python_alternative %{_bindir}/panel
%{python_sitelib}/panel
%{python_sitelib}/panel-%{version}.dist-info

%files -n jupyter-panel
%license LICENSE.txt
%{_jupyter_config} %{_jupyter_servextension_confdir}/panel-client-jupyter.json
%{_jupyter_config} %{_jupyter_server_confdir}/panel-client-jupyter.json
%endif

%changelog
* Wed Oct  2 2024 Ben Greiner <code@bnavigator.de>
- Add exclude-package-lock.patch
  * Do not install package-lock.json
  * Avoids non-reproducible local registry port
  * boo#1231254 gh#openSUSE/obs-service-node_modules#41
* Wed Sep 25 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.5.0
  * This release, while technically a minor release hugely expands
    the scope of what is possible in Panel. In particular the
    introduction of the new panel.custom module makes it trivially
    easy to create new JS and React based components using modern
    tooling, a first-class developer experience and support for
    compilation and bundling. We are incredibly excited to see
    which new components you build using this approach. This
    release also includes native integration with FastAPI, such
    that you can now run Panel apps natively on an existing FastAPI
    server. We also introduce a number of new components, improved
    the developer experience, and squashed a huge number of bugs,
    particularly for the Tabulator component.
  [#]# Features
  * Allow building custom ESM based JSComponent and ReactComponent
    (#5593)
  * Add Placeholder pane (#6790)
  * Add FileDropper widget (#6826)
  * Add ChatStep component to show/hide intermediate steps (#6617)
  * Add TimePicker widget (#7013)
  * Add PyComponent baseclass (#7051)
  * Add native support for running Panel on FastAPI server (#7205)
  [#]# Enhancements
  * Allow callbacks after append and stream (#6805)
  * Enable directory uploads with FileInput (#6808)
  * Make autoreload robust to syntax errors and empty apps (#7028)
  * Add support for automatically determining optimal
    Tabulator.page_size (#6978)
  * Various typing improvements (#7081, #7092, #7094, #7132)
  * Display value for player (#7060)
  * Optimize rendering and scrolling behavior of Feed (#7101)
  * Implement support for multi-index columns in Tabulator (#7108)
  * Add placeholder while loading to ChatFeed (#7042)
  * Allow streaming chunks to HTML and Markdown panes (#7125)
  * Show Player interval value on click (#7064)
  * Expose Player options to scale and hide buttons (#7065)
  * Add on_keyup and value_input for CodeEditor (#6919)
  * Detect WebGL support on BrowserInfo (#6931)
  * Tweak ChatMessage layout (#7209, #7266)
  * Add nested editor to Tabulator (#7251)
  * Support anchor links in HTML and Markdown panes (#7258, #7263)
  [#] Bug fixes
  * Ensure Gauge is responsively sized (#7034)
  * Ensure Tabulator sorters are correctly synced (#7036)
  * Ensure Tabulator selection is consistent across paginated,
    sorted and filtered states (#7058)
  * Do not propagate clicks on input elements in Card header
    (#7057)
  * Ensure Tabulator range selection applies to current view
    (#7063)
  * Ensure Tabulator.selection is updated when indexes change
    (#7066)
  * Ensure Tabulator can be updated with None value (#7067)
  * Fix issues with PYTHONPATH in Jupyter Preview (#7059)
  * Ensure Tabulator styling is correctly applied on multi-index
    (#7075)
  * Fix various scrolling related Tabulator issues (#7076)
  * Ensure Tabulator data is updated after filters are changed
    (#7074)
  * Allow controlling DataFrame pane header and cell alignment
    (#7082)
  * Highlight active page in Tabulator using Fast Design (#7085)
  * Ensure follow behavior works when streaming to paginated
    Tabulator (#7084)
  * Avoid events boomeranging from frontend (#7093)
  * Correctly map Tabulator expanded indexes when paginated,
    filtered and sorted (#7103)
  * Ensure custom HoloViews backends do not error out (#7114)
  * Ensure events are always dispatched sequentially (#7128)
  * Ensure 'multiselect' Tabulator.header_filter uses 'in' filter
    function (#7111)
  * Ensure no content warning is not displayed when template is
    added (#7164)
  * Make it easy to prompt user for input in ChatFeed (#7148)
  * Fix LaTeX pane MathJax rendering (#7188)
  * Ensure OAuth expiry is numeric and can be compared (#7191)
  * Correctly detect max depth of NestedSelect if level is empty
    (#7194)
  * Make --setup/--autoreload/--warm work with --num-procs (#6913)
  * Ensure error rendering application does not crash server
    (#7223)
  * Refactor state.notifications to fix pyodide (#7235)
  * Handle setting None value on DateRangePicker (#7240)
  * Add header_tooltips parameter to Tabulator (#7241)
  * Fix issue using Tabulator.header_filter with recent Pandas
    versions (#7242)
  * Fix setting of Dial background (#7261)
  * Fix issues when loading multiple times in a Jupyter(Lab)
    session (#7269)
  [#]# Compatibility and Updates
  * Update to Bokeh 3.5.x
  * Update Tabulator to 6.2.1 (#6840)
  * Update to latest Pyscript (2024.08.01) and Pyodide (0.26.2)
    (#7016)
  * Add compatibility for latest Textual (#7130)
  [#]# Deprecation and API Warnings
  * PasswordInput and TextAreaInput no longer inherit directly from
    TextInput (#6593)
  * Remove deprecated panel.depends.param_value_if_widget function
    (#7202)
* Tue May  7 2024 Daniel Garcia <daniel.garcia@suse.com>
- Bring back package %%build from source, removing binary .whl
  distribution from package.
* Sun Apr 21 2024 Todd R <toddrme2178@gmail.com>
- update to 1.4.1
  + Enhancements
  * Allow rendering raw `IPython.display` output in dashboard builder
  * Improve snapping behavior and add undo functionality in dashboard builder UI)
  + Bug Fixes
  * Fix layout persistence issues in dashboard builder
  * Ensure `Perspective` loads in notebooks and docs
  * Allow full reset of dashboard builder layout
  * Fix issues with `VTK` colormap serialization
  * Allow `Tabulator` `HTMLTemplateFormatter` to reference multiple columns
  * Fix loading spinner in converted app without template
  * Avoid unnecessary rescroll on Column
  * Fix dynamically updating description tooltips
  * Ensure Perspective is fully loaded before attempting render)
  * Ensure busy indicators are always reset
- update to 1.4.0
  + Features
  * Add `EditableTemplate` to support dashboard builder UI in Jupyter
  * Add `ChatAreaInput` as default text input widget for `ChatInterface`
  * Add `NestedSelect` widget
  * Add Panel tutorials
  * Add `DateRangePicker` widget
  * Add `Feed` layout and use it as layout for `ChatFeed`
  * Add `WebP` pane
  * Add `ButtonIcon`
  * Add `Textual` pane
  + Enhancements
  * Improve `--autoreload` by using watchfiles and selectively reloading packages
  * Load loading indicator from file instead of inlining
  * Allow providing additional stylesheets in `card_params`
  * Add `scroll` options to permanently toggle on layouts
  * Allow choosing position of frozen columns on `Tabulator`
  * Add help message on `ChatFeed`
  * Ensure CSS can be applied to every aspect of `ChatMessage`
  * Add HoloViz logos as `ChatMessage` avatars
  * Add `gap` parameter to `FlexBox`
  * Set default `step` of `DatetimeRangeSlider` to 1 minute
  * Add support for passing objects reference to `FlexBox`
  * Allow editable sliders to be embedded
  * Add `message` into `css_classes` to `ChatMessage` markup
  * Allow appending objects to the `ChatMessage` header & footer
  * Add ability to declare icon label
  * Add title and settings and fix datetime to `Perspective`
  * Warn user if loading extension in VSCode or Colab without `jupyter_bokeh`
  * Throttle updates to Boolean indicators
  * Add `ParamRef` baseclass for `ParamFunction` and `ParamMethod`
  * Add ability to Skip `Param<Ref|Function|Method>` updates
  * Add `Param<Ref|Method|Function>` and `ReactiveExpr` to panes module
  * Set up `param.rx` display accessor on import
  * Allow using Carto tiles in `DeckGL`
  * Improve `VTKJS` binary serialization
  * Ensure component CSS is pre-loaded if possible, avoiding flicker on load
  + Bug fixes
  * Add resize handler for `FloatPanel`
  * Fix serving of global template in notebook
  * Ensure `Tabulator` renders in collapsed `Card`
  * Fix issues with `VTK`, `VTKVolume` and `VTKJS` due to webgpu renderer
  * Ensure `HTML` and other markup panes can be emptied
  * Ensure collapsed `Card` does not cause stretching
  * Ensure notebook preview always uses server resources
  * Remove animation from loading spinner without spin
  * Ensure model is only added/removed from Document once
  * Ensure `loading_indicator` resets when configured with context manager
  * Fix modal overflow and resizing issues
  * Ensure that ripple matches notification size
  * Fully re-render `CodeEditor` on render calls ensuring it displays correctly
  * Ensure `FileDownload` button has correct height
  * Ensure `HTML` model is redrawn if `stylesheets` is emptied
  * Allow providing custom template
  * Ensure `Debugger` renders without error
  * Ensure pending writes are dispatched in order and only from correct thread
  * Ensure layout reuses model if available
  * Improved exception handler in unlocked message dispatch
  * Fix display of interactive `Matplotlib`
  * Ensure `Plotly` pane renders and hides correctly in `Card`
  * Fix issues rendering widget components with `Fast` design
  * Fix binary serialization from JS -> Pyodide
  * Avoid overeager garbage collection
  * Fix floating point error in `IntRangeSlider`
  * Load JS modules from relative path
  * Ensure no events are dispatched before the websocket is open
  * Ensure `Markdown` parsing does not choke on partial links
  * Fixes to ensure larger `PDF`s can be rendered
  * Ensure `IPywidget` comms are only opened once
  * Fixes for message handling in Jupyter Preview context
  * Fix unnecessary loading of `ReactiveHTML` resources
  * Ensure `Template.raw_css` has higher precedence than default template CSS
  * Avoid asyncio event loop startup issues in some contexts
  * Ensure column subset is retained on `Tabulator.style`
  * Ensure bokeh mathjax bundle when mathjax extension is loaded in notebook
- Switch to wheel to avoid npm attempting to rebuild resources.
  This doesn't work without a network and needs brittle workarounds that can change between releases.
- Update dependencies
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- skip python39 (nothing provides python39-branca)
* Wed Mar  6 2024 Ben Greiner <code@bnavigator.de>
- Also skip testing ipympl and holoviews on python 3.9
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Stop testing with plotly and ipython on python 3.9: Those are
  no longer available.
* Fri Jan 26 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.8:
  * Ensure `ReactiveHTML` correctly resets `Event` parameters
  * Fix `ChatFeed` / `ChatInterface` tests and async generator
    placeholders
  * Fix logic when looking up `pn.state.curdoc`
  * Handle margin=None in layout sizing mode computation
  * Updates for compatibility with pandas 2.2
  * Improve documentation on `TextAreaInput`
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.7:
  * Support using an SVG for `ToggleIcon`
  * Add resizable param to `TextAreaInput`
  * Improve date and datetime picker functionality
  * Add activity indicator to `ChatMessage`
  * Lazily import bleach HTML sanitizer
  * Fix alignment issues in chat components
  * Fix generator placeholder and optimize updates in Chat
    components
  * Fix issue with callback future handling on Chat components
  * Fix bug in Chat interfaces related to `pn.state.browser_info`
  * Allow instantiating empty `Matplotlib` pane
  * Ensure icon displays inline with text on `FileDownload`
  * Fix styling of links in `Tabulator` fast theme
  * Fix passing of `card_params` on `ChatFeed`
  * Handle `Tabulator.title_formatter` if is type `dict`
  * Fix `per_session` caching
  * Correctly reshape nd-arrays in `Plotly` pane
  * Handle NaT values on `Perspective` pane
  * Do not rerender output if `ReplacementPane` object identity
    is unchanged
  * Tabulator: fix valuesLookup set up for older list-like
    editors
  * Fix pyodide loading message styling issues
  * More complete patch for the `TextEditor` to support being
    rendered in the Shadow DOM
  * Add guard to `Tabulator` ensuring that it does not error when
    it is not rendered
  * Fix race conditions when instantiating Comm in Jupyter
    causing notifications to break
  * Handle duplicate attempts at refreshing auth tokens
  * Upgrade Plotly.js to 2.25.3 to address CVE-2023-46308
  * Add `Design` and `Theme` explanation documentation
  * Fix pyodide execution in documentation
  * Fix wrong and broken link
  * Use GoatCounter for website analytics
  * Add Dask How to guide
  * Fix `Material` template notebook .show() call
  * Add missing item in docstring
  * Ploomber Cloud deployment documentation
  * Correct duplicate wording
  * Update JupyterLite Altair example to latest API
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.6:
  * This patch release addresses a major regression in server
    performance introduced in 1.3.5 along with some additional
    minor fixes. We want to welcome @nenb as a new contributor
    and want to thank the maintainers @ahuang11, @maximlt and
    @philippjfr for their contributions to this release.
  * Add explicit size option to ToggleIcon (#6092)
  * Fix execution of OAuth of callback to refresh `access_token`
  * Fix `ChatReactionIcons` alignment and trigger reactions
    correctly (#6086)
  * Change `Column` `scroll_position` default value from `None`
    to `0` (#6082)
  * Fix issue with accumulating callbacks on server (#6091)
  * Ensure `ReactiveExpr` renders in pyodide (#6097)
  * Ensure `TooltipIcon` description can be updated (#6099)
  * Fix IPyWidgets rendering in `BootstrapTemplate` (#6100)
  * Fix padding and alignment of `FileDownload` (#6101)
* Wed Dec 20 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.3.5:
  * Add support for timestamp timezones for ChatMessage
    (gh#holoviz/panel#5961).
  * Replace whitelist blacklist with allowlist denylist
    (gh#holoviz/panel#5975).
  * Allow stopping respond callbacks midway on ChatInterface
    (gh#holoviz/panel#5962).
  * Add support for Image.caption (gh#holoviz/panel#6003).
  * Improvements for Fast template styling
    (gh#holoviz/panel#6023).
  * Replace Player widget unicode icons with SVG for more
    consistency (gh#holoviz/panel#6030).
  * Elaborate on ChatInterface callback exception summary
    (gh#holoviz/panel#6046).
  * Add ToggleIcon widget (gh#holoviz/panel#6034).
  * Use minified Tabulator.js (gh#holoviz/panel#6060).)
  * Support rendering GeoDataFrame and GeoSeries in DataFrame pane
    (gh#holoviz/panel#6061).
  * Optimize rendering of ChatMessage (gh#holoviz/panel#6069).
  * Apply smaller optimizations for Viewable and ChatMessage
    (gh#holoviz/panel#6074).
  * Add bottom padding to MaterialTemplate
    (gh#holoviz/panel#6075).
  * Update mapbox-gl version for DeckGL pane
    (gh#holoviz/panel#6077).
  * Remove duplicate property definition of VizzuChart.config
    (gh#holoviz/panel#5947).
  * Remove stray print in Tabulator styler handling
    (gh#holoviz/panel#5944).
  * Fix bug when clearing pn.cache before anything has been cached
    (gh#holoviz/panel#5981).
  * Fix obj.save() when threading is enabled
    (gh#holoviz/panel#5993).
  * Fix Matplotlib responsiveness and improve reference notebook
    (gh#holoviz/panel#5973).
  * Gracefully handle non-decodable access_token
    (gh#holoviz/panel#5994).
  * Ensure onload callbacks scheduled during or after load are
    still executed (gh#holoviz/panel#6005).
  * Don't attempt to set Tabulator text_align on Bokeh formatters
    that don't support it (gh#holoviz/panel#6010).
  * Correctly set error page to be rendered on auth failure
    (gh#holoviz/panel#6014).
  * Fix ChatInterface post callback for default
    (gh#holoviz/panel#5998).
  * Ensure matplotlib backend is set correctly in pyodide worker
    (gh#holoviz/panel#6029).
  * Synchronously create Document patch message to avoid race
    conditions (gh#holoviz/panel#6028).
  * Do not inline CSS if it can be loaded from CDN
    (gh#holoviz/panel#6039).
  * Fix ChatMessage reactions icon rendering
    (gh#holoviz/panel#6034).
  * Fix issues with ChatInterface stop ensuring send button is
    re-enabled and placeholder removed (gh#holoviz/panel#6033).
  * Ensure that Design does not override properties on HoloViews
    pane (gh#holoviz/panel#6051).
  * Ensure async callbacks correctly dispatch events when
    Websocket is locked (gh#holoviz/panel#6052).
  * Fix state.add_periodic_callback when callback is async
    (gh#holoviz/panel#6053).
  * Do no update objects inplace unless explicitly requested
    fixing issues with non-updating components
    (gh#holoviz/panel#6055).
  * Update sizing of Panel models dynamically
    (gh#holoviz/panel#6054).
  * Make panel.chat.langchain import lazy improving import time
    (gh#holoviz/panel#6056).
  * Change prominence of TooltipIcon (gh#holoviz/panel#6057).
  * Improve reactive expression notebook (gh#holoviz/panel#5960).
- Disable another flaky test that suffers timeout issues:
  test_server_on_load_after_init.
- Export export PYTEST_DEBUG_TEMPROOT to current dir to avoid
  write permission issues.
* Sun Dec 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.4:
  * Allow passing partial function to tabulator filter (#5912)
  * Allow defining custom callbacks for `ChatInterface` buttons
  * Fix regression when setting `text_align` and
    `HTMLTemplateFormatter` on `Tabulator` (#5922)
  * Ensure notifications are correctly destroyed (#5924)
  * Fix header overflow issues in `FastGridTemplate` (#5935)
  * Ensure `Audio` model respects sizing (#5936)
  * Persist Tabulator selection across pages when
    `pagination='remote'` for all selection modes (#5929)
  * Ensure `Tabulator` styler subset logic is not lost (#5938)
  * Fix regression in OAuth when `id_token` does not contain user
    key (#5939)
  * Ensure Vega/Altair plot with responsive width/height respects
    fixed width/height value when set (#5940)
  * Ensure `BrowserInfo` is imported by default (#5942)
* Fri Nov 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.3.2
  * This micro-release focuses on a number of performance
    improvements, speeding up the initial rendering of simple apps
    by 2x in many cases. In addition it includes a number of
    smaller enhancements for various widgets, better support for
    async and threading and a number of bug fixes related to
    authentication, the Tabulator widget and a few other items. We
    are very pleased to welcome @isumitjha and @fohria as new
    contributors and want to thank our core team including
    @maximlt, @Hoxbro, @MarcSkovMadsen, @ahuang11 and @philippjfr
    for their continuing contributions.
  [#]# Performance
  * Speed up Pane.clone (#5848)
  * Speed up config attribute access (#5851)
  * Cache templates loaded from string (#5854)
  * Only load extension entrypoints once (#5855)
  * Do not freeze document models unless needed (#5864)
  [#]# Enhancements
  * Use the compiled version of Pyodide by default (#5808)
  * Add support for AutocompleteInput.search_strategy parameter
    (#5832)
  * Use stdlib_module_names when determining pyodide dependencies
    (#5818)
  * Add Tabulator.sortable parameter (#5827)
  * Add delay for tooltip to show up for buttons (#5860)
  * Add serialize method on ChatMessage and ChatFeed (#5764)
  * Allow running onload and defer_load tasks on threads (#5865)
  * Allow Image panes for ChatMessage.avatar (#5870)
  * Allow async callbacks on FileDownload (#5878)
  * Allow running scheduled tasks on threads (#5879)
  [#]# Bug fixes
  * Fix Google OAuth default scopes (#5823)
  * Fix logic for cleaning up OAuth user (#5824)
  * Set text_align correctly if Tabulator is given Bokeh formatter
    (#5866)
  * Fix FileDownload embed=True style for Fast design (#5875)
  * Enable Tabulator selection across pages with
    pagination="remote" and selectable="checkbox" (#5889)
  * Fix rendering of VTK colorbar (#5902)
  * Ensure HoloViews DynamicMap updates when widget dimension has
    unit (#5904)
  * Add space between MaterialTemplate app and site title separator
    (#5905)
  * Consistently handle errors during authentication (#5909)
  [#]# Compatibility
  * Updates for Numpy 2.0 compatibility (#5817)
  * Improve notebook handling when loading bokeh dev versions
    (#5820)
- Version 1.3.1
  * This micro-release primarily ships a variety of bug and
    regression fixes focusing on auth, the chat components, and
    WASM (i.e. PyScript and Pyodide) support. It also adds an
    enhancement to the auth components that now makes it possible
    to let users access applications as a guest. Many thanks to our
    new contributors @art3xa, @polivbr and @tupui as well as our
    core development team including @MarcSkovMadsen, @maximlt,
    @ahuang11 and @philippjfr.
  [#]# Enhancements
  * Add support for authenticating as guest using OAuth and basic
    auth components (#5743)
  [#]# Bug fixes
  * Ensure ColorMap widget correctly handles shared layout and
    display parameters (#5732)
  * Fix accessing refreshed access_token (#5734)
  * Ensure Markdown code blocks always wrap (#5738)
  * Fix returning state.user_info if no id_token is present in
    cookies (#5747)
  * Fix Widget.from_param type annotation (#5754)
  * Fix auto send for ChatInterface with TextAreaInput (#5762)
  * Add support for iframe srcdoc on Location (#5774)
  * Ensure Tabulator.style applies correctly with changing data
    (#5757)
  * Ensure panel convert can correctly detect transformers_js
    import (#5772)
  * Adjust ReactiveHTML css resources for relative paths (#5779)
  * Ensure invalid query parameters warn instead of erroring
    (#5781)
  * Apply pyscript CSS by default without the splashscreen (#5784)
  * Ensure components which require DOM element to be attached can
    be rendered in Card (#5786)
* Tue Oct 24 2023 Markéta Machová <mmachova@suse.com>
- Update to 1.3.0
  * Integrate support for param reactive expressions and expose pn.rx
  * Implement ChatMessage, ChatFeed and ChatInterface components
  * Unify OAuth implementations and refresh access_token
  * Add ColorMap widget
  * Add unit to widget in HoloViews pane if provided
  * Allow registering global on_session_destroyed callback
  * Implement auto_grow on TextAreaInput
  * Add ability to redirect users from authorization callback
  * Add support for Path object in FileDownload
  * Add authorization_code and password based OAuth login handlers
  * Add format to EditableFloatSlider and EditableIntSlider
  * Add support for decorating async functions with pn.io.cache
  * Map param.Bytes to FileInput widget
  * Add support for Python 3.12 and drop Python 3.8 support
  * Upgrade to Param 2.0 as minimum required version
  * Compatibility with Bokeh 3.3.0
  * more bugfixes, see upstream CHANGELOG.md
* Sun Sep 17 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to vesion 1.2.2:
  * Enhancements:
  - Add scroll button, auto-scroll and scroll position options
    to Column (gh#holoviz/panel#5245, gh#holoviz/panel#5365,
    gh#holoviz/panel#5369, gh#holoviz/panel#5403)
  - Add cache busting to server CSS resources
    (gh#holoviz/panel#5414)
  - Add Tabulator.title_formatters parameter
    (gh#holoviz/panel#5421)
  - Provide the the accessed path to authorization checks
    (gh#holoviz/panel#5386)
  - Add Perspective click events (gh#holoviz/panel#5430)
  - Add and improve pn.io.hold and pn.io.immediate_dispatch
    context managers to control events (gh#holoviz/panel#5444)
  - Allow to passing basic_login_template argument to panel
    server (gh#holoviz/panel#5454)
  * Bug fixes:
  - Ensure BasicAuth forwards to original URL after login
    (gh#holoviz/panel#5357)
  - Correct return types from threading.Thread to
    panel.io.server.StoppableThread (gh#holoviz/panel#5396)
  - Various guards and fixes ensuring Tabulator re-renders
    correctly (gh#holoviz/panel#5410, gh#holoviz/panel#5412)
  - Avoid extra executions when executing periodic callback with
    counter (gh#holoviz/panel#5344)
  - Ensure updates to DataModel are correctly scheduled on the
    event loop (gh#holoviz/panel#5360)
  - Fixes for displaying single newlines in Markdown output and
    add renderer_options (gh#holoviz/panel#5376)
  - Allow update of Accordion title without updating content
    (gh#holoviz/panel#5413)
  - Fix authentication handling when prefix is set
    (gh#holoviz/panel#5422)
  - Fix serialization issues affecting TextLayer objects in
    DeckGL (gh#holoviz/panel#5427)
  - Fix height responsiveness of Perspective pane
    (gh#holoviz/panel#5429)
  - Ensure FileDownload button can be clicked anywhere
    (gh#holoviz/panel#5431)
  - Ensure ReactiveHTML children are rendered just like other
    models (gh#holoviz/panel#5434)
  - Set Perspective properties correctly to avoid causing
    unfocus on keypresses (gh#holoviz/panel#5432)
  - Ensure FloatPanel correctly exposes its children to allow
    linking (gh#holoviz/panel#5433)
  - Do no reset Tabulator options if DataFrame indexes are
    unchanged (gh#holoviz/panel#5436)
  - Add ability to work around issues when removing series from
    ECharts (gh#holoviz/panel#5435)
  - Fix race conditions when initializing and rendering
    IPyWidgets in notebooks (gh#holoviz/panel#5462)
  - Tweak Accordion CSS to remove gaps and avoid border overlap
    (gh#holoviz/panel#5460)
  - Ensure columns are deleted when updating traces on Plotly
    pane to avoid corruption (gh#holoviz/panel#5464)
  - Invalidate layout when TextEditor CSS loads
    (gh#holoviz/panel#5465)
  - Ensure FloatPanel reflects closed status
    (gh#holoviz/panel#5466)
  - Fix handling of string dtypes on Perspective pane
    (gh#holoviz/panel#5467)
  * Documentation updates.
- Drop panel-pr5185-bokeh3.2.patch: incorporated upstream.
- Disable test_local_pdf_file since local pdf file missing from
  tarball.
* Wed Jul  5 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.1.1
  [#]# Enhancements
  * Implement per_session cache (#5117)
  * Enhancements for ChatBox including methods to update rows and
    hide names (#5118, #5118)
  [#]# Bug fixes
  * Fix Progress indicator sizing_mode (#5051)
  * Fix various ChatBox issues (#5065, #5101, #5101)
  * Ensure kernel shutdown futures are not collected in Jupyter
    server extension (#5069)
  * Add bokeh version check for notebook to better support bokeh
    dev versions (#5071, #5093)
  * Fix false warning emitted when constructing a Param pane with
    throttled or onkeyup (#5078)
  * Allow to updating/clearing enabled_dates on DatetimePicker
    (#5089)
  * Ensure session arguments are correctly parsed by Jupyter
    executor (#5106)
  * Fix defer_load handling (#5107)
  * Fix styling with filters in Tabulator (#5110)
  * Fix issues when using in filter with single value on Tabulator
    (#5125)
  * Add fallback if ReactiveHTML shadow DOM lookup fails (#5126)
  * Allow automatic loading of extensions during launch and warn
    about missing extensions (#5144)
  * Correctly process fields on Vega (and altair) selections
    (#5145)
  * Immediately dispatch ColumnDataChangedEvent fixing Plotly plots
    not updating (#5147)
  [#]# Compatibility
  * Correctly serialize new IPyWidget models on creation (#5114)
  * Ensure we handle JupyterLab 4 comm messages correctly (#5140)
  [#]# Backward compatibility
  * Renamed Trend parameter title to name (#5092)
- Add panel-pr5185-bokeh3.2.patch gh#holoviz/panel#5185
  * Bump bokeh upper pin
- Don't test on 32-bit it fails randomly
* Wed Jun  7 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.1.0
  * This is the first minor release in the 1.x series with a number
    of new features and small bug fixes. The main features we are
    excited about are the new ChatBox widget added by @ahuang11 and
    support for reactive generators. Many thanks to @ahuang11,
    @philippjfr and @Hoxbro for contributing to this release and
    our amazing community for reporting issues.
  [#]# Features
  * Add the ChatBox widget (#4702)
  * Add a standalone TooltipIcon indicator (#4909)
  * Implement support for reactive generator functions (#5019)
  * Allow setting on_* handlers in constructor (#5026)
  * Allow controlling initial Template sidebar state (#5033)
  [#]# Bug fixes
  * Handle height responsiveness of HoloViews layout correctly
    (#5009)
  * Apply Plotly toolbar colors depending on template (#5012)
  * Fix Fast Design style variables (#5015)
  * Allow reactive updates to override constant parameters (#5032)
  * Fix Tabulator header filter styling (#5038)
  * Ensure Jupyter extensions warns users if app has no contents
    (#5041)
- Version 1.0.4
  * Another micro-release in the 1.0.x series addressing small
    issues reported by our engaged community. Many thanks to
    @ahuang11, @simzer, @alexmilowski and the core contributors
    @droumis, @Hoxbro and @philippjfr for contributing to this
    release.
  * Fix global loading spinner (#4936)
  * Fix issues resolving whether IPyWidget model (#4939)
  * Fix recursive and inplace updates on reactive panes (#4946,
    [#4958])
  * Fix issues with single Select widget (#4947)
  * Ensure CSS config parameters can be passed to Template
    constructor (#4948)
  * Fixed vizzu data series type conversion for datetime (#4955)
  * Small documentation fixes (#4943, #4960)
  * Fix icon on Toggle and Button widget (#4961)
  * Fix Volume definition on Video pane
  * Ensure icon renders on Toggle button (#4969) (#4970)
  * Ensure Card.header_color is correctly applied (#4971)
  * Update param.List signatures to suppress warnings (#4973)
  * Fix font loading in Vanilla template (#4975)
  * Guard is_file check on Windows (#4985)
  * Fix serialization of Plotly.selection_data (#4987)
  * Speed up dynamic layout updates (#4989)
- Version 1.0.3
  * Another micro-release in the 1.0.x series with a number of
    smaller bug fixes. Most importantly this resolves issues with
    loading indicators and with apps converted to the
    pyodide-worker target. Many thanks to @n3011, @Hoxbro and
    @philippjfr for contributing to this release.
  * Resolve _repr_jpeg_ methods correctly (#4904)
  * Fix handling of queued events in pyodide worker (#4913)
  * Various fixes for loading indicator (#4915)
  * Allow -1 in Tabs.active and allow recovering from closed tabs
    (#4920)
  * Ensure HoloViews layout is correctly initialized when center is
    set (#4921)
  * Ensure VSCode editor does not apply white background to Panel
    output (#4923)
  * Do not error on deserialization errors in notebooks (#4927)
  * Ensure basic auth provider works when dynamically starting
    server (#4926)
  * Ensure Param pane name is updated when object changes (#4928)
  * Align functionality and styling of FileDownload with Button
    (#4929)
  * Fix equality comparisons of parameter values when updating a
    Pane (#4934)
  * Warn about ignored widget parameters on Param pane (#4934)
- Version 1.0.2
  * A micro-release in the 1.0.x series with a number of bug fixes
    and documentation tweaks. Many thanks to @jbednar and
    @philippjfr for contributing to this release.
  [#]# Bug fixes
  * Ensure Design stylesheets are not replaced when updating
    component stylesheets (#4883)
  * Ensure tooltips are rendered correctly as HTML (#4887)
  * Fix loading of index page resources (#4891)
  * Ensure FloatPanel can be rendered in classic notebooks (#4892)
  * Attempt rendering output in notebooks even if not all resources
    have been initialized (#4893)
  * Do not load large bokeh-mathjax bundle in notebooks by default
    (#4895)
  * Make Fast template sidebar opening transition smoother (#4898)
  * Ensure new items added to Card layout are rendered (#4899)
  * Fix logo rendering in BasicAuth template (#4900)
- Version 1.0.1
  * A micro-release fixing some small issues discovered in Panel
    1.0. Thank you to @droumis, @Hoxbro and @philippjfr for
    contributing fixes.
  [#]# Bug fixes
  * Ensure Reactive objects wrapped in reactive are re-rendered
    correctly (#4868)
  * Tweaks for Material Design component inset label styling
    (#4877)
  * Ensure SlidesTemplate slides changes trigger updates in the
    pn.state.location.hash (#4878)
- Version 1.0.0
  * The Panel 1.0 release is finally here and it brings a huge
    number of improvements. The largest improvements in this
    release come from an upgrade from Bokeh 2.x to Bokeh 3.x. Bokeh
    overhauled its internal layout engine and stylesheet handling,
    making applications significantly more performant and
    customizable going forward.
  * This release marks a huge step forward in the usability of
    Panel but is also just a first step in leveraging many of the
    new capabilities that the updated layout engine and design
    system affords. In the coming months we will continue to
    improve and polish the UI and UX and make it easier for you to
    extend Panel as needed.
  * For now we want to thank the many people that contributed to
    this release either by contributing directly or by testing and
    providing feedback. Many thanks to the core contributors
    @MarcSkovMadsen, @Hoxbro, @maximlt, @jbednar, @droumis and
    @philippjfr and the outside contributors @ahuang11, @cdeil,
    @MridulS, @AndrewMaged814, @midnighter and @wendrul.
  [#]# Major Features
  * Add new and highly performant layout engine, addressing many
    performance and layout issues (#4326, #4463, #4491, #4503,
    [#4522], #4690)
  * Add unified Design and Theme system (#4413, #4475, #4466,
    [#4540], #4548, #4770, #4792, #4793, #4801)
  * Implement support for passing parameters, widgets and bound
    functions by reference for simple and powerful reactivity
    (#4495, #4505, #4603, #4606)
  * Some of the changes related to the new layout engine and design
    system will require small updates to your existing
    applications. To make this transition as smooth as possible we
    have provided an upgrade/migration guide.
  [#]# New Components
  * Add Swipe layout (#3007)
  * Add Switch widget (#4130)
  * Add Vizzu pane (#4226, #4739)
  * Add BrowserInfo model to expose browser window and navigator
    APIs (#4533)
  * Add BasicAuth provider for quick password based auth (#4684)
  * Add FloatPanel layout (#4707, #4711)
  * Add a SlidesTemplate based on reveal.js to create interactive
    presentations (#4798)
  [#]# Major enhancements
  * Improved Markdown rendering (#4688)
  * Add support for tooltips on widgets (#4130, #4621,
    [#4643])
  * Ensure .ipynb and .md based apps can be used as --index (#4432)
  * Add support for selecting format and encoding for Matplotlib
    image output and implemented responsive Image sizing (#4514)
  * Add support for icons on Button (#4797)
  * Add generic Image pane that auto-detects the image filetype
    (#4551)
  * Add support for writing applications in Markdown (#4602)
  * Improve support for inline resources for Jupyter (#3013, #4787)
  * Add ability to reuse sessions to speed up rendering (#3679,
    [#4658])
  * Improve notebook resource and extension loading (#4752)
  * Add ability to add global loading spinner to application(s)
    (#4659)
  [#]# Deprecations & API changes
  [#]## Compatibility
  * Bokeh 3 compatibility (#4098, #4117, #4129, #4140, #4150,
    [#4275], #4467, #4435, #4441, #4449, #4448, #4508)
  * Upgrade plotly.js to 2.18.0 (#4320)
  * Upgrade Tabulator to 5.4 and optimize rendering (#4482)
  * Upgrade Echarts to 5.4.1 (#4538)
  * Upgrade pyodide (0.23.1) and pyscript versions (#4344)
  * Add support for altair and vega-lite v5 (#4488)
  * Add support for latest versions of ipywidgets (#4716, #4766,
    [#4779])
  [#]## Deprecations
  * Deprecate IDOM pane (#4293, #4323)
  * Deprecate Viewable.app (#4293)
  * Deprecate Viewable.pprint (#4347)
  * Deprecate and remove RGGPlot
  * Rename Ace to CodeEditor (#4627)
  [#]## API changes & Backward Compatibility
  * Pandas is now only a (lazy) runtime dependency (#4411)
  * Tabulator.frozen_rows now respects the order of rows in the
    data instead of the order in which the frozen_rows were defined
    (#4482)
  * Make margin defaults consistent across widgets and panes
    (#4528)
  * Extension calls must specify all required extensions (#4562)
  * The .embed method now returns a Mimebundle object for rendering
    (#4791)
  * Remove panel examples CLI command and pyct dependency (#4691)
  * Expose all layout components in top-level API (#4696)
  [#]# Other Enhancements
  [#]## Configuration
  * Allow to set the log level of the Admin logger (#3495)
  * Add pn.state.served to simplify determining whether script is
    executed as an application or in an interactive session (#4252)
  * Add pn.config.loading_indicator to determine whether to show
    loading indicator by default (#4259)
  [#]## Jupyter
  * Improve startup, error handling and shutdown of Jupyter kernels
    (#4364)
  * Log errors in JupyterLab preview to server logs (#4773)
  * Support binary JS -> Python communication in notebooks (#4635)
  * Modify sys.path when running inside Jupyter Kernel (#4489)
  [#]## Pyodide
  * IPython display compatibility in pyodide builds (#4270)
  * Ensure panel convert respects pn.config (#4359)
  * Fix notification support in Pyodide (#4387)
  [#]## Miscelleanous
  * Handle cancelling and empty value edit events on Tabulator
    (#4343)
  * Add favicon to base template (#4626)
  * Ensure CrossSelector filters apply on each keystroke (#4339)
  * Do not re-create Vega.selections object unless selections
    changed (#4497)
  * Standardize parameter mapping APIs (#4386)
  * Add Plotly.link_figure parameter (#4333)
  * Add support for .JPEG file extension in the JPG pane (#4532)
  * Make periodic callback counter a parameter (#4134)
  * Add Echarts events (#2174)
  * Additional cache support (#4663, #4667)
  [#]# Bug fixes
  * Fix caching on undecorated Parameterized method (#4332)
  * Ensure that global notification object can be used inside
    notebook callbacks (#4331)
  * Ensure hash_funcs are applied recursively in cache (#4334)
  * Fix cache FIFO policy bug (#4789)
  * Fix specifying custom index with relative path (#4288)
  * Fix issue reusing FileDownload model (#4328)
  * Fix DeckGL tooltip handling (#4628)
  * Fix NumPy integer/floating checks on Perspective (#4366)
  * Ensure memray profiler temporary file is flushed (#4666)
  * Fix mimetype issue on windows (#4738)
  * Fix Plotly undefined value errors for eventdata (#4355)
  [#]## Tabulator
  * Ensure updates to Tabulator formatter or editor updates model
    (#4296, #4781)
  * Ensure Tabulator internal _index_mapping is updated on stream
    (#4292)
  * Ensure Tabulator header filters aren't treated as regex (#4423)
  * Ensure Tabulator styles are re-applied when local pagination
    changes (#4795)
  [#]## Jupyter
  * Ensure JupyterLab preview works on Windows (#4819)
  * Ensure notifications are enabled even if hv.extension has been
    loaded (#4330)
* Fri Mar 31 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.14.4
  [#]# Bugs
  * Fix Tabulator client-side string filters by not parsing them as
    regex (4423)
  * Fix the RGGPlot pane (#4380)
  * Fix panel examples command by ensuring examples are correctly
    packaged (#4484)
  * Fix event generation by considering NaNs as equal when
    comparing Numpy arrays (#4481)
  * Use cache from previous sessions when using to_disk (#4481)
  * Fix relative imports when running inside Jupyter Kernel (#4489)
  * Do not re-create Vega.selections object unless selections
    changed (#4497)
  [#]# Enhancements
  * Add support for altair and vega-lite v5 (#4488)
- Version 0.14.3
  * This release introduces a large number of bug fixes and minor
    enhancements. Due to the upcoming release of Panel 1.0 we have
    also made the unconventional decision to issue new deprecation
    in a micro release. Specifically the IDOM pane and Viewable.app
    and Viewable.pprint methods have been scheduled for
    deprecation. Many thanks to the contributors to this release
    which include @wendrul, @droumis and the core team
    @MarcSkovMadsen, @maximlt, @Hoxbro and @philippjfr.
  [#]# Bugs
  [#]## Tabulator
  * Ensure streamed rows on Tabulator can be edited (#4292)
  * Ensure changes on Tabulator formatter and editor models are
    reflected in frontend (#4296)
  * Ensure cancelling edit does not clear cell on Tabulator (#4343)
  * Ensure inserting empty data on numeric column in Tabulator does
    not error (#4343)
  [#]## Notebook
  * Fix issues rendering components as ipywidgets for some versions
    of ipykernel (#4289)
  * Add warning if custom resources could not be loaded in notebook
    (#4329)
  * Ensure notifications are enabled even if hv.extension has been
    loaded (#4330)
  * Ensure global notification object can be used inside notebook
    callbacks (#4331)
  [#]## Type definitions
  * Fix return type of Widget.from_param (#4335)
  * Ensure type annotation allows str and PathLike objects on
    panel.serve (#4336)
  * Fix type annotations on panel.io.convert.convert_app(s) (#4342)
  [#]## Misc
  * Ensure markdown links render correctly in template sidebar
    (#4222)
  * Improve .applies for ECharts and DeckGL (#4224)
  * Fix specifying custom --index with relative path (#4288)
  * Skip on_load callbacks in liveness check (#4302)
  * Ensure re-rendered FileDownload still fetches live data (#4328)
  * Fix handling of panel.cache on undecorated Parameterized method
    (#4332)
  * Ensure user provided hash_funcs are applied in panel.cache
    (#4334)
  * Fix plotly eventdata undefined val (#4355)
  * Ensure panel convert respects panel.config options (#4359)
  * Propagate options from HoloViews and Bokeh plots to enclosing
    Pane (#4360)
  * Propagate options from dynamic components such as ParamMethod
    and Interactive to enclosing layout (#4360)
  [#]# Minor enhancements
  * Allow to set the log level of the Admin logger (#3495)
  * Make refresh_token available in Auth (#4227)
  * Simplify determining whether script is executed as application
    with pn.state.served property (#4252)
  * Add loading_indicator to global config (#4259)
  * IPython display compatibility in pyodide builds (#4270)
  * Split PanelJupyterExecutor into separate module (#4276)
  * Allow dynamic loading of javascript modules in ReactiveHTML
    (#4319)
  * Add Plotly.link_figure parameter (#4333)
  * Ensure CrossSelector filters apply on each keystroke (#4339)
  * Improve startup, error handling and shutdown of Jupyter kernels
    in jupyter_server_extension (#4364)
  [#]# Compatibility and Version Updates
  * Upgrade plotly.js to 2.10.1 (#4320)
  * Upgrade to pyodide 0.22.1 in panel convert (#4334)
  * Upgrade to pyscript 2022.12.01 in panel convert (#4334)
  * Fix compatibility of Perspective pane with Numpy 1.24 (#4362)
  [#]# Deprecations
  * Add deprecation warning to IDOM pane (#4293)
  * Add deprecation warning for Viewable.app and Viewable.pprint
    methods (#4293, #4347)
* Fri Jan 13 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.14.2
  * This release primarily focuses on bug fixes. In particular it
    resolves various issues with support for rendering ipywidgets
    (particularly in ipywidgets>=8.0) and also fixes a number of
    issues with the Jupyter Server previews.
  [#]# Enhancements
  * Add support for Tqdm.process_map (#4093)
  * Support non-vtkPolyData types in vtk synchronizer (#4124)
  * Allow invoking convert functions from pyodide (#4135)
  * Support step format in date sliders (#4152)
  * Add a Reacton component to simplify rendering (#4190)
  [#]# Bugs
  * Ensure Jupyter server extension serves resources, extensions
    and paths correctly (#4083, #4133, #4202)
  * Ensure IPyWidget comm does not break when new widget is
    rendered (#4091)
  * Improving detection of comms in VSCode and Google Colab (#4115)
  * Ensure .js mimetype is served correctly on Windows (#4118)
  * Ensure unhiding Tabulator columns renders cells correctly
    (#4119)
  * Ensure embedded Slider widgets initialize with correct default
    (#4121)
  * Handle missing event loop in thread gracefully (#4123)
  * Ensure Matplotlib pane handles explicit width/height settings
    correctly (#4128)
  * Allow Viewer to render servable but non-viewable objects
    (#4131)
  * Fix regression in tracking sessions in admin interface (#4132)
  * Ensure Tabs headers do not scroll unncessarily (#4146)
  * Ensure Location model reports as idle (#4159)
  * Fix auth error template rendering (#4162)
  * Fix issues with value on EditableSlider when it is outside
    fixed_start / fixed_end range (#4169)
  * Ensure ipywidgets events are handled the same way as regular
    events (#4171)
  * Don't raise TypeError for class which contains __panel__
    (#4174)
  * Do not dispatch events if bokeh Document is set to hold events
    (#4178)
  * Execute onload callbacks immediately in pyodide app (#4191)
  * Improve IPyWidget kernel handling in server contexts (#4195)
  * Fix rendering of IPyWidget with child views in the notebook
    (#4197)
- PEP517 build
* Mon Nov 21 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.14.1
  * This release primarily addresses regressions introduced in
    0.14.0 and various long standing bugs. Many thanks to external
    contributors @liu-kan and @KedoKudo and the maintainers
    @Hoxbro, @maximlt and @philippjfr for contributing a number of
    fixes.
  [#]# Minor enhancements
  * Improve support for requests in pyodide (#3973)
  * Add option to clear value of DatetimePicker (#3990)
  * Add support for hashing dates in pn.cache (#4004)
  * Silence EMPTY_LAYOUT warnings (#4056)
  [#]# Compatibility
  * Fix Jupyterlite and latest PyScript compatibility (#4040)
  [#]# Bugs
  [#]## Webassembly conversion
  * Correctly handle resource mode in when converting to
    WebAssembly (#3967)
  [#]## Jupyter and Server
  * Correctly handle future exceptions on threads (#3977)
  * Fix panel serve index template (#3980)
  * Do not error if curdoc has been destroyed (#3994)
  * Ensure extensions loaded in jupyter kernel are served by
    StaticHandler (#4000)
  * Various fixes for OAuth handling with pn.serve (#4006)
  * Fix bug in on_load callback exception handling (#4007)
  * Ensure periodic callbacks are only started on main thread
    (#4011)
  * Ensure jupyter server extension handles explicit root_dir
    (#4029)
  * Ensure futures are correctly awaited when executed on thread
    (#4031)
  [#]## Components
  * Ensure Tabulator handles filtering on edited values correctly
    if show_index=False (#3988, #4016)
  * Ensure Tabulator declares numeric sorter for numeric dtypes
    (#3999)
  * Fix regression initializing DiscreteSlider with non-integer
    value (#4009)
  * Ensure that template.config.raw_css is correctly applied
    (#4018)
  * Fix handling MenuButton clicks when split=True (#4021)
  * Ensure styling on Tabulator with empty DataFrame does not error
    (#4028)
  * Allow changing level on Debugger widget (#4057)
- Release 0.14.0
  * This release focuses on three main themes:
  - Support for running Panel apps entirely in the browser using
    WebAssembly (via Pyodide and PyScript)
  - Improvements in the app-user experience by making it easier
    to build responsive and performant applications
  - Improvements in the developer experience through static
    typing and docstrings.
  * Many, many thanks to everyone who filed issues or contributed
    to this release. In particular we would like to thank @janimo,
    @xavArtley, @thuydotm, @jmosbacher, @dmarx, @2WoLpH, @ipopa144,
    @sdc50 for contributions and @philippjfr, @Hoxbro, @maximlt,
    and @MarcSkovMadsen for ongoing maintenance and development.
  [#]# Features
  * Add support for converting Panel apps to pyscript/pyodide
    (#3817, #3830, #3851, #3856, #3857, #3858, #3860, #3861, #3863,
    [#3864], #3868, #3878)
  * Manage our own CDN to improve performance and reliability for
    delivering JS payloads (#3867, #3870)
  * Add ability to defer_load of components (#3882)
  * Add pn.widget helper function (#1826, #3589)
  * Add config.exception_handler to easily capture, log and notify
    users about errors (#3893)
  * Implement pn.cache function for memoization support (#2411)
  * Rewrite server extension to run Panel applications in kernels
    so that previews run in the same environment as the deployed
    app (#3763)
  * Add ability to define authorization callback (#3777)
  * Support memray profiler (#3509)
  * Add liveness endpoint (#3832)
  * Add ability to configure exception handler (#3896)
  [#]# Enhancements
  * Ensure OAuth redirects to requested app and retains query
    arguments (#3555)
  * Add extension entry point (#3738)
  * Update Admin Logs page to use Tabulator (#3694)
  * Ensure location.unsync unsets query params (#3806)
  * Allow None value on numeric sliders and LiteralInput (#3174)
  * Allow serving admin panel with pn.serve (#3798)
  * Improve ReactiveHTML loop support and validation (#3813)
  * Support declaring Perspective.plugin_config pane (#3814)
  * Do not flicker busy indicator during --autoreload check (#3804)
  * Improve robustness of state.curdoc in threaded and async
    contexts (#3776, #3810, #3834)
  * Support datetime bounds for DatetimePicker and
    DatetimeRangePicker (#3788)
  * Allow setting the Oauth provider using environment variables
    (#3698)
  * Implement Player.value_throttled (#3756)
  * Ensure that URL query parameters are preserved during OAuth
    (#3656)
  * Improve Markdown code syntax highlighting (#3758)
  * Ensure components do not re-render if background or loading
    parameters change (#3599)
  * Add ability to define admin dashboard plugins (#3668)
  * Do not calculate embed state for disabled widgets (#3757)
  * Add hard bounds to editable sliders (#3739)
  * Add bundling of shared resources (#3894)
  * Add Tabulator as default param.DataFrame widget (#3912)
  [#]# Compatibility & Version updates
  * Support ipywidgets>=8.0 (#3782)
  * Bump jsoneditor package (#3838)
  * Upgrade to Tabulator 5.3.2 (#3784)
  * Improve Django compatibility (#3843, #3835)
  * Remove all usage of deprecated Pane
  [#]# Bugs
  [#]## Server
  * Ensure closed websocket does not cause errors
  * Handle session and websocket close cleanly (#3769)
  * Fix prefix handling for admin page (#3809)
  * Support admin dashboard in multi-process deployments (#3812)
  * Improve document cleanup when not invoked using server_destroy
    (#3842)
  * Ensure pn.state.execute dispatches immediately if possible
    (#3859)
  * Ensure autoload.js resources are appropriately prefixed (#3873)
  [#]## Notebook
  * Fix support for copying cells and creating new views in
    JupyterLab (#3652)
  * Ensure output renders in VSCode notebook with latest ipywidgets
    (#3765)
  * Resolve issues with Jupyter slowdown due to event_loop patching
    on Windows (#3770)
  * Ensure old comm managers do not raise errors in notebook
    (#3853)
  * Simplify rendering of ipywidget (#3937)
  [#]## Tabulator
  * Do not re-render Tabulator on css_classes or background change
    (#3598)
  * Ensure expand icon updates on Tabulator.expanded change (#3703)
  * Update page Parameter when pagination is 'local' (#3704)
  * Do not apply sorters on Tabulator cell edits (#3744)
  * Ensure Tabulator.controls renders (#3768)
  * Ensure correctness of event row and selection indices in
    Tabulator (#3771, #3841)
  * Fix issues with frontend and backend sorters being out of sync
    in Tabulator (#3825, #3839)
  * Fix default values of a list header filter in Tabulator (#3826)
  * Fix the edit event with a python filter in Tabulator (#3829)
  * Disable client-side date filtering on Tabulator (#3849)
  * Support editing of pandas masked array dtypes in Tabulator
    (#3850)
  * Fix issues editing a cell when client-side filtering applied
    (#3852)
  * Do not recompute data when local pagination is enabled (#3854)
  * Don't skip filtering when the column name is undefined (#3862)
  [#]## Misc
  * Fix FileInput.save (#3579)
  * Fix issues with Matplotlib.high_dpi option (#3591, #3594)
  * Ensure layout recomputes on HTML/Markdown re-rerender (#3616)
  * Allow overriding all widget parameters on Param pane (#3754)
  * Ensure DatePicker start/end are transformed when jslinked
    (#3759)
  * Ensure notifications can be enabled without a template (#3820)
  * Ensure ReactiveHTML inline callbacks on loop variables return
    correct node (#3840)
  * Ensure that Perspective does not take precedence on empty dict
    (#3936)
  * Improve sizing_mode behavior when width/height are specified
    (#3955)
  * Do not load notyf resources unless notifications are enabled
    (#3958)
* Wed Jun 22 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.13.1:
  * Add repr to cell and edit events (gh#holoviz/panel#3434).
  * Improvements for pyodide handling (gh#holoviz/panel#3444,
    gh#holoviz/panel#3508, gh#holoviz/panel#3511).
  * Add support for Plotly animation frames
    (gh#holoviz/panel#3449).
  * Implement single and multi-selection in Vega pane
    (gh#holoviz/panel#3470, gh#holoviz/panel#3499,
    gh#holoviz/panel#3505).
  * Add typehints to help developers and users
    (gh#holoviz/panel#3476).
  * Add pn.state.execute method to run callbacks in the right
    context (gh#holoviz/panel#3550).
  * Add support for asynchronous on_edit/on_click Tabulator
    callbacks (gh#holoviz/panel#3550).
  * Add DatetimeRangeSlider widget (gh#holoviz/panel#3548).
  * Many bug fixes, see
    https://github.com/holoviz/panel/releases/tag/v0.13.1
* Sun May  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.13.0:
  * Major new features for the Tabulator widget:
  - Client-side header filters
  - Expandable rows
  - on_click and on_edit callbacks
  * Add support for listenting to events on Vega pane.
  * Add JSONEditor and TextEditor widgets.
  * Add ability to display notifications in toasts.
  * LaTeX rendering now supported in Markdown and HTML panes.
  * Ability to schedule recurring tasks independent of any running
    applications.
  * An admin dashboard to allow you to monitor, debug and profile
    your applications.
  * Support rendering Panel objects in Jupyterlite and Pyodide.
  * Built-in threading.
  * Easily extend Panel with your own components and Templates.
  * A code-of-conduct was added.
  * Numerous other fixes and enhancements, see
    <https://blog.holoviz.org/panel_0.13.0.html>.
* Tue Feb 15 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.12.6:
  * Always load imported bokeh extensions (gh#holoviz/panel#2957).
  * Fix regression rendering HoloViews plotly backend
    (gh#holoviz/panel#2961).
  * Do not run Ace import on initialization
    (gh#holoviz/panel#2959).
  * Improve handling of ReactiveHTML cleanup
    (gh#holoviz/panel#2974, gh#holoviz/panel#2993).
  * Ensure empty Str has same height as non-empty
    (gh#holoviz/panel#2981).
  * Ensure Tabulator supports grouping on numeric columns
    (gh#holoviz/panel#2987).
  * Fix Tabulator with multi-index and pagination
    (gh#holoviz/panel#2989).
  * Allow index as column name in table widgets
    (gh#holoviz/panel#2990).
  * Ensure TemplateActions component does not have height
    (gh#holoviz/panel#2997).
- Bump python-param requirement, at least version 0.12.0 is
  required.
- Drop %%config tag from file installed to /usr/etc in keeping with
  rpmlintrc recommendation.
- Disable an additional test: test_server; requires network.
* Sun Sep 19 2021 Ben Greiner <code@bnavigator.de>
- Add missing bleach runtime dependency
* Sat Sep 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.12.3:
  * Patch Bokeh to fix show() (gh#holoviz/panel#2748).
- Changes from version 0.12.2:
  * Enhancements:
  - Add option to hide constant parameters on Param pane
    (gh#holoviz/panel#2637).
  - Added on_session_destroyed callback (gh#holoviz/panel#2659).
  - Stricter validation for linking syntax in
    ReactiveHTML._template (gh#holoviz/panel#2689).
  * Bug fixes:
  - Improved thread safety (gh#holoviz/panel#2631).
  - Ensure sessions get distinct files in config
    (gh#holoviz/panel#2646).
  - Fix bug when updating Trend data (gh#holoviz/panel#2647).
  - Ensure sorters are applied correctly after updating
    Tabulator value (gh#holoviz/panel#2639).
  - Correctly reflect filtered data on Tabulator.selection
    (gh#holoviz/panel#2676).
  - Unescape child literal HTML in ReactiveHTML
    (gh#holoviz/panel#2690).
  - Ensure Trend indicator can be rendered in layout
    (gh#holoviz/panel#2694).
  * Documentation:
  - Enhance templates docs (gh#holoviz/panel#2658).
  - Add Folium reference notebook (gh#holoviz/panel#2672).
  * Compatibility:
  - Add support for bokeh 2.4 (gh#holoviz/panel#2644,
    gh#holoviz/panel#2687, gh#holoviz/panel#2696).
- Drop mp3.mp3, mp4.mp4 as Sources and
  panel-pr2636-fixtests.patch: upstream PR merged.
* Thu Aug 26 2021 Ben Greiner <code@bnavigator.de>
- Use -s in pytest call
* Mon Aug 23 2021 Ben Greiner <code@bnavigator.de>
- Update to version 0.12.1
  * Big Changelog since 0.11
    https://github.com/holoviz/panel/blob/master/CHANGELOG.md
  * New Features in 0.12:
    Add ReactiveHTML
    Add Terminal Widget based on xterm.js (#2090)
    Adding a DatetimePicker widget (#2107, #2135)
    Add editable sliders (#2111, #2133, #2208)
    Add FlexBox layout (#2233, #2511)
    Add ability to configure global template (#2271)
    Add GridStack layout (#2375)
    Add PDF pane (#2444)
    Add /panel-preview endpoint for Jupyter server extension
    (#2341, #2361)
    Add Tqdm Indicator (#2079)
  * Deprecations:
    Remove add_periodic_callback method (#2439)
    Remove deprecated panel.callbacks modules
    Remove deprecated Ace pane and Audio Widget (#2427)
    Remove Progress widget docs (#2451)
    Tabulator no longer loaded by default, must be initialized with
    pn.extension('tabulator')
- Add missing test data and patch
  * mp3.mp3
  * mp4.mp4
  * panel-pr2636-fixtests.patch
  * gh#holoviz/panel#2636
* Thu Apr  1 2021 Ben Greiner <code@bnavigator.de>
- Move configuration file to new jupyter-panel package in order to
  avoid conflicts for multiple python flavors
- Skip failing test gh#holoviz/panel#2101
* Thu Mar 18 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.11.1:
  * Enhancements:
  - Allow setting horizontal and vertical alignment separately
    (gh#holoviz/panel#2072).
  - Expose widgets visible property (gh#holoviz/panel#2065).
  - Allow bind to extract dependencies and evaluate other
    dynamic functions (gh#holoviz/panel#2056).
  - Allow setting root_directory on FileSelector widget
    (gh#holoviz/panel#2086).
  * Bug fixes:
  - Fixed loading of jQuery in BootstrapTemplate
    (gh#holoviz/panel#2057).
  - Fix VTK imports to ensure VTKVolume pane renders grids
    (gh#holoviz/panel#2071).
  - Fix loading of template resources from relative paths
    (gh#holoviz/panel#2067).
  - Fix Spinner component overflow (gh#holoviz/panel#2070).
  - Handle integer column names on Perspective widget
    (gh#holoviz/panel#2069).
  - Fix bundling of template resources (gh#holoviz/panel#2076).
  - Fix value_throttled in pn.depends decorator
    (gh#holoviz/panel#2085).
  * Compatibility: Switch GitHub OAuth to use header authorization
    token (gh#holoviz/panel#2073).
* Thu Mar  4 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.11.0:
  * Major features:
  - A Perspective pane based on the FINOS Perspective library
    (gh#holoviz/panel#2034).
  - Implement --autoreload functionality for the Panel server
    (gh#holoviz/panel#1983).
  - Add --warm option to panel serve, useful for pre-loading
    items into the state cache (gh#holoviz/panel#1971).
  - Add ability to define JS modules and Template specific
    resources (gh#holoviz/panel#1967).
  - panel.serve now supports serving static files and Bokeh
    apps, not just Panel apps (gh#holoviz/panel#1939).
  - Add a TrendIndicator for conveniently showing history and
    value of a numeric quantity (gh#holoviz/panel#1895).
  - Add TextToSpeech widget (gh#holoviz/panel#1878).
  - Add SpeechToText widget (gh#holoviz/panel#1880).
  - Add loading parameter and spinners to all components
    (gh#holoviz/panel#1730, gh#holoviz/panel#2026).
  - Add IDOM pane to develop interactive HTML components in
    Python (gh#holoviz/panel#2004).
  - Add powerful new Tabulator widget for flexible and
    configurable display of tabular data (gh#holoviz/panel#1531,
    gh#holoviz/panel#1887).
  * Enhancements:
  - Add watch argument to bind function so that covers all the
    features of pn.depends (gh#holoviz/panel#2000).
  - Add format parameter to DatetimeRangeInput widget
    (gh#holoviz/panel#2043).
  - Allow ParamMethod and ParamFunction to evaluate lazily
    (gh#holoviz/panel#1966).
  - Add value_input parameter to TextInput widgets
    (gh#holoviz/panel#2007).
  - Implement Glyph3dMapper support for VTK panes
    (gh#holoviz/panel#2002, gh#holoviz/panel#2003).
  - Add Jupyter server extension to serve resources
    (gh#holoviz/panel#1982).
  - Enhancements for DarkTheme (gh#holoviz/panel#1964).
  - Add refresh functionality to FileSelector
    (gh#holoviz/panel#1962).
  - Add support for Auth0 authentication
    (gh#holoviz/panel#1934).
  - Avoid recursive preprocessing slowing down rendering
    (gh#holoviz/panel#1852).
  - Add support for per-layer tooltips on DeckGL pane
    (gh#holoviz/panel#1846).
  - Add Viewer baseclass for custom user components
    (gh#holoviz/panel#2045).
  * Bug fixes:
  - Fixed FileSelector file icon on selected files
    (gh#holoviz/panel#2046).
  - Drop query args when checking URLs (gh#holoviz/panel#2037).
  - Fix Card.header_background propagation
    (gh#holoviz/panel#2035).
  - Disable GoldenTemplate sidebar when empty
    (gh#holoviz/panel#2017).
  - Ensure Card.collapsed and Accordion.active parameters are
    synced (gh#holoviz/panel#2009).
  - Fix inline resources when saving (gh#holoviz/panel#1956).
  - Switch Param pane widget type when bounds (un)defined
    (gh#holoviz/panel#1953).
  * Compatibility:
  - Compatibility with Bokeh>=2.3 (gh#holoviz/panel#1948,
    gh#holoviz/panel#1988, gh#holoviz/panel#1991).
  - Updated ECharts pane to 5.0.2 of JS library
    (gh#holoviz/panel#2016).
  * Documentation: Document pn.bind in API user guide
    (gh#holoviz/panel#1973).
- Add BuildRequires: jupyter-notebook-filesystem and install
  jupyter notebook configuration file.
* Sun Feb 14 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 build (no scipy)
* Mon Jan  4 2021 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.10.2:
  * Fix various issues with Template CSS (#1663, #1742)
  * Fix BytesIO/StringIO buffers as input to image xpanes (#1711)
  * Fix out-of-bounds errors when assigning to GridSpec with
    fixed ncols (#1721)
  * Fix deserialization issues for Plotly.hover_data (#1722)
  * Fixed updating of Alert parameters after initialization (#1725)
  * Fix ordering of items added to Template areas (#1736)
  * Fix interactivity for items in Card (#1750)
  * Ensure onload callbacks are only run once (#1746)
  * Allow overriding items in grid based templates (#1741)
  * Ensure ECharts and ipywidget rerender when in Card (#1765)
  * Ensure template dark theme persists on HoloViews plots (#1764)
  * Fix responsive height in Plotly pane (#1770)
  * Ensure image panes resize in width and height (#1777)
  * Fix issues with Location.sync serialization (#1784)
  * Add throttled argument to interact (#1259)
  * ECharts pane now loads echarts-gl for 3D support (#1785)
  * Ensure CheckBoxGroup and CheckButtonGroup support arbitrary
    objects as options (#1793)
  * Improved OAuth encryption key validation (#1762)
  * Add progress option to .save method (#1776)
- Fix conflict with parallel installable python3 flavors because
  of incorrect python_expand usage with docs
  gh#openSUSE/python-rpm-macros#66
- Fix npm bundling errors during install
- Make multibuild test flavor in order to avoid dependency cycle
  with python-holoviews
- The hidden .version file is actually necessary (e.g. holoviews
  checks the version) -- add python-panel-rpmlintrc
* Sat Oct 31 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.10.1:
  * Enhancements: Add pn.bind function to bind parameters to a
    function (gh#holoviz/panel#1629).
  * Bug fixes:
  - Fix WidgetBox CSS (gh#holoviz/panel#855).
  - Fix CSS load order in Templates (gh#holoviz/panel#1698).
  - Allow setting DiscreteSlider orientation
    (gh#holoviz/panel#1683).
  - Ensure JS callbacks and links are only set up once on
    templates (gh#holoviz/panel#1700).
  - Initialize pipeline only once (gh#holoviz/panel#1705).
  - Allow using NumberInput as Param pane widget
    (gh#holoviz/panel#1708).
- Disable python2 builds since dependencies (e.g. python-bokeh) no
  longer support python2.
* Sat Jun  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
